@@ -34,13 +34,13 @@
 #include <tqregexp.h>
 #include <tqeventloop.h>
 
-//KDE includes
-#include <klocale.h>
+//TDE includes
+#include <tdelocale.h>
 #include <kcombobox.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kprogress.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 //Lucence includes
 //#include "CLucene.h"
@@ -73,7 +73,7 @@ void StrongsResultClass::initStrongsResults(void) {
 	count = result.Count();
 	if (!count)
 		return;
-	KApplication::kApplication()->processEvents( 1 ); //1 ms only
+	TDEApplication::kApplication()->processEvents( 1 ); //1 ms only
 	srList.clear();
 	// for whatever reason the text "Parsing...translations." does not appear.
 	// this is not critical but the text is necessary to get the dialog box
@@ -85,7 +85,7 @@ void StrongsResultClass::initStrongsResults(void) {
 	progress->raise();
 	for (index = 0; index < count; index++){
 		progress->progressBar()->setProgress( int( (index*100) / count ) );
- 		KApplication::kApplication()->processEvents( 1 ); //1 ms only
+ 		TDEApplication::kApplication()->processEvents( 1 ); //1 ms only
 
 		key = TQString::fromUtf8(result.GetElement(index)->getText());
 		text = render.renderSingleKey(key, modules, settings);
@@ -547,22 +547,22 @@ const TQString CSearchResultPage::highlightSearchedText(const TQString& content,
 			index += length;
 		}
 	}
-	//qWarning("\n\n\n%s", ret.latin1());
+	//tqWarning("\n\n\n%s", ret.latin1());
 	return ret;
 };
 
 /** Initializes the signal slot conections of the child widgets, */
 void CSearchResultPage::initConnections() {
-	connect(m_resultListBox, TQT_SIGNAL(keySelected(const TQString&)),
-			this, TQT_SLOT(updatePreview(const TQString&)));
-	connect(m_moduleListBox, TQT_SIGNAL(moduleSelected(CSwordModuleInfo*)),
-			m_resultListBox, TQT_SLOT(setupTree(CSwordModuleInfo*)));
-	connect(m_moduleListBox, TQT_SIGNAL(moduleChanged()),
-			m_previewDisplay->connectionsProxy(), TQT_SLOT(clear()));
-	connect(m_analyseButton, TQT_SIGNAL(clicked()), TQT_SLOT(showAnalysis()));
+	connect(m_resultListBox, TQ_SIGNAL(keySelected(const TQString&)),
+			this, TQ_SLOT(updatePreview(const TQString&)));
+	connect(m_moduleListBox, TQ_SIGNAL(moduleSelected(CSwordModuleInfo*)),
+			m_resultListBox, TQ_SLOT(setupTree(CSwordModuleInfo*)));
+	connect(m_moduleListBox, TQ_SIGNAL(moduleChanged()),
+			m_previewDisplay->connectionsProxy(), TQ_SLOT(clear()));
+	connect(m_analyseButton, TQ_SIGNAL(clicked()), TQ_SLOT(showAnalysis()));
    // connect the strongs list
-   connect(m_moduleListBox, TQT_SIGNAL(strongsSelected(CSwordModuleInfo*, TQStringList*)),
-         m_resultListBox, TQT_SLOT(setupStrongsTree(CSwordModuleInfo*, TQStringList*)));
+   connect(m_moduleListBox, TQ_SIGNAL(strongsSelected(CSwordModuleInfo*, TQStringList*)),
+         m_resultListBox, TQ_SLOT(setupStrongsTree(CSwordModuleInfo*, TQStringList*)));
 }
 
 /** Shows a dialog with the search analysis of the current search. */
@@ -616,20 +616,20 @@ void CSearchOptionsPage::setSearchText(const TQString& text) {
 
 /** Initializes this page. */
 void CSearchOptionsPage::initView() {
-	connect( m_searchTextCombo, TQT_SIGNAL(activated( const TQString& )),
-				m_searchTextCombo, TQT_SLOT( addToHistory( const TQString& ))
+	connect( m_searchTextCombo, TQ_SIGNAL(activated( const TQString& )),
+				m_searchTextCombo, TQ_SLOT( addToHistory( const TQString& ))
 			);
-	connect( m_searchTextCombo, TQT_SIGNAL(returnPressed ( const TQString& )),
-				m_searchTextCombo, TQT_SLOT(addToHistory(const TQString&))
+	connect( m_searchTextCombo, TQ_SIGNAL(returnPressed ( const TQString& )),
+				m_searchTextCombo, TQ_SLOT(addToHistory(const TQString&))
 			);
 	TQToolTip::add(m_searchTextCombo, CResMgr::searchdialog::options::searchedText::tooltip);
 
 	m_syntaxButton->setIconSet(SmallIconSet("contexthelp"));
-	connect( m_syntaxButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(syntaxHelp()));
+	connect( m_syntaxButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(syntaxHelp()));
 
 	m_chooseModulesButton->setIconSet(SmallIconSet("wizard"));
-	connect(m_chooseModulesButton, TQT_SIGNAL(clicked()),
-			this, TQT_SLOT(chooseModules()));
+	connect(m_chooseModulesButton, TQ_SIGNAL(clicked()),
+			this, TQ_SLOT(chooseModules()));
 	TQToolTip::add
 		(m_chooseModulesButton, CResMgr::searchdialog::options::moduleChooserButton::tooltip);
 		
@@ -638,8 +638,8 @@ void CSearchOptionsPage::initView() {
 	refreshRanges();
 
 	m_chooseRangeButton->setIconSet(SmallIconSet("configure"));
-	connect(m_chooseRangeButton, TQT_SIGNAL(clicked()),
-			this, TQT_SLOT(setupRanges()));
+	connect(m_chooseRangeButton, TQ_SIGNAL(clicked()),
+			this, TQ_SLOT(setupRanges()));
 
 	//set the initial focus
 	m_searchTextCombo->setFocus();
@@ -673,8 +673,8 @@ void CSearchOptionsPage::setModules( ListCSwordModuleInfo modules ) {
 /** Opens the modules chooser dialog. */
 void CSearchOptionsPage::chooseModules() {
 	CModuleChooserDialog* dlg = new CModuleChooserDialog(this, modules());
-	connect(dlg, TQT_SIGNAL(modulesChanged(ListCSwordModuleInfo)),
-			this, TQT_SLOT(setModules(ListCSwordModuleInfo)));
+	connect(dlg, TQ_SIGNAL(modulesChanged(ListCSwordModuleInfo)),
+			this, TQ_SLOT(setModules(ListCSwordModuleInfo)));
 	dlg->exec();
 }
 
@@ -782,3 +782,5 @@ bool CSearchOptionsPage::hasSearchScope() {
 
 	} //end of namespace Options
 } //end of namespace Search
+
+#include "csearchdialogpages.moc"
